@@ -16,7 +16,9 @@ class Compass:
             for idx, column in enumerate(columns):
                 try:
                     timestamp = row[idx].getTime() / 1000
-                    tuple = tuple + (datetime.datetime.fromtimestamp(timestamp),)
+                    tuple = tuple + (datetime.datetime.fromtimestamp(timestamp).astimezone().isoformat(),)
+                    print ('formatted date: ', datetime.datetime.fromtimestamp(timestamp).astimezone().isoformat())
+                    # tuple = tuple + (datetime.datetime.fromtimestamp(timestamp),)
                 except AttributeError:
                     tuple = tuple + (row[idx],)
             tuples.append(tuple)
@@ -24,16 +26,25 @@ class Compass:
         return tuples
 
 
-    def load_to_dataframe(self, tableName, columns, schema):
+    def load_to_dataframe(self, tableName, columns, schema, where=[]):
         cpHook = JdbcHook(log_sql=True, jdbc_conn_id=self.__compass_conn_id)
-        strColumns = ",".join(columns)
-        sql = f'select {strColumns} from {schema}.{tableName}'
+        strColumns = ",".join('"' + columnName.upper() + '"' for columnName in columns)
+
+        if len(where) > 0:
+            whereClause = "WHERE " + " AND ".join('"' + cond['column'].upper() + '"' + ' ' + cond['symbol'] + ' ' +
+                                                  (f"'{cond['value']}'" if not str(cond['value']).isdigit() else str(
+                                                      cond['value']))
+                                                  for cond in where)
+        else:
+            whereClause = ""
+
+        sql = f'select {strColumns} from {schema}.{tableName} {whereClause}'
         # print(sql)
         db = cpHook.get_pandas_df(sql=sql)
         # print(db)
         return db
 
-    def load_to_tuples(self, tableName, columns, schema):
+    def load_to_tuples(self, tableName, columns, schema, where=[]):
         df = self.load_to_dataframe(tableName=tableName, columns=columns, schema=schema)
         tuples = self.__dataFrameToTuples(df=df, columns=columns)
         # print(tuples)
